function SOL = HardwareInTheLoop(Fa,funControl)

    % setando timer de controle
    controletm = timer('ExecutionMode','fixedRate','Period',1/Fa,...
                       'TimerFcn',@acaoDeControle);    

    % setup da placa de aquisicao
    ai = analoginput('nidaq','Dev1');ao = analogoutput('nidaq','Dev1');
    addchannel(ai,0:2);addchannel(ao,0);
    set(ai,'ChannelSkewMode','Equisample');ai.ChannelSkew;
    
    % setando timer da animao/simulao da planta
    fps = 20; % frames por segundo
    plantatm = timer('ExecutionMode','fixedRate','Period',1/fps,...
                     'TimerFcn',@atualizaModeloPlanta);
           
    % iniciando a planta
    Objetos = plotaPlanta([]); % criando objetos grficos
    set(Objetos.figID,'CloseRequestFcn',@closeFigure);
    set(Objetos.StartStop,'Callback',@startStopPlanta);
    [Estado,Objetos] = modeloPlanta([],Objetos,fps); % estados iniciais
    
    % iniciando vetores para salvar os valores no tempo
    SOL = [];tVec = [];ref = [];pot = [];tac = [];uctrl = [];ik = 0;
    
    % iniciando registro de tempo de execuo
    tSim = tic;tPrev = toc(tSim);
    
    % aguardando at finalizar a animao
    uiwait(Objetos.figID); % pausar a funo at a figura ser fechada
    
    
    % funo de ao do controle
    function acaoDeControle(~,~)
        
        % verificando instante de tempo
        tAct = toc(tSim);
        
        % adquirindo input
        sample = getsample(ai);
        pk = sample(2);wk = sample(3);
        
        % atualizando estado
        Estado.Var.PosManipulador = pk;
        Estado.Var.VelManipulador = wk;
                   
        % calculando valor de controle
        [uk,ik] = funControl(tAct,tPrev,...
                             Estado.Var.Ref,...
                             Estado.Var.PosManipulador,...
                             Estado.Var.VelManipulador,ik);
                          
        % saturando e enviando output
        if abs(uk) > 5
            uk = sign(uk)*5;
        end
        putsample(ao,uk);
        tPrev = tAct;
        
        % atualizando vetores
        tVec(end+1) = tAct;
        ref(end+1) = Estado.Var.Ref;
        pot(end+1) = Estado.Var.PosManipulador;
        tac(end+1) = Estado.Var.VelManipulador;
        uctrl(end+1) = uk;
        
    end % function acaoDeControle


    % funo do timer de animao/simulao da planta industrial
    function atualizaModeloPlanta(~,~)

        [Estado,Objetos] = modeloPlanta(Estado,Objetos,fps);
        
    end % function modeloPlanta


    % funo para fechar a figura
    function closeFigure(~,~)
        
        % tratando o caso em que o usurio fecha a janela sem dar stop
        if isempty(SOL)
            SOL(end+1).tVec = tVec;
            SOL(end).ref = ref;
            SOL(end).pot = pot;
            SOL(end).tac = tac;
            SOL(end).uctrl = uctrl;
        end
        
        % interrompendo movimento, parando e deletando timers e figura
        putsample(ao,0);
        stop(controletm);
        delete(controletm);
        stop(plantatm);
        delete(plantatm);
        delete(Objetos.figID);
        
    end % function closeFigure


    % funo de callback do boto Start/Stop
    function startStopPlanta(~,~)
        
        switch get(Objetos.StartStop,'String')
            case 'Start' 
                % levando motor pra posio inicial
                returningToPos0(ai,ao,Estado.Var.PosManipulador);
                tSim = tic;tPrev = toc(tSim); % iniciando tempo
                start(plantatm);
                start(controletm);
                set(Objetos.StartStop,'String','Stop');
            case 'Stop'
                stop(plantatm);
                stop(controletm);
                Objetos = plotaPlanta(Objetos.figID); % resetando posies
                set(Objetos.figID,'CloseRequestFcn',@closeFigure);
                set(Objetos.StartStop,'Callback',@startStopPlanta);
                [Estado,Objetos] = modeloPlanta([],Objetos,fps); % resetando estados
                
                % salvando soluo
                SOL(end+1).tVec = tVec;
                SOL(end).ref = ref;
                SOL(end).pot = pot;
                SOL(end).tac = tac;
                SOL(end).uctrl = uctrl;
                
                % iniciando vetores para prximo start
                tVec = [];ref = [];pot = [];tac = [];uctrl = [];ik = 0;
            
        end % switch
        
    end % function startStopPlanta
   

end % function HardwareInTheLoop