function [Estado,Objetos] = modeloPlanta(Estado,Objetos,fps)

    %% setando requisitos da planta
    TEMPO_ESTEIRA = 1; % tempo[s] que as esteira de entrada e sada levam
    TEMPO_LIM_PORTA_ABERTA = 0.6; % tempo[s] que a porta pode ficar aberta
    TEMPO_BOLO_PRONTO = 5; % tempo[s] que o bolo leva pra ficar pronto
    TEMPO_BOLO_PASSADO = 1; % tempo[s] limite pro bolo sair do forno
    CRITERIO_PARADA_POS_POSIT = 0.06; % assentamento [0-1]
    CRITERIO_PARADA_POS_NEGAT = 0.01; % assentamento [0-1]
    CRITERIO_PARADA_VEL = 0.01; % assentamento [rad/s / Komega]
    TOL_SOBRESSINAL = 0.01; % tolerncia do sobressinal [V]
    
    %% setando estados para condio inicial
    
    % estados do bolo para facilitar identificao do id
    EM_ESPERA = 0;ENTRANDO = 1;CENTRO = 2;PRONTO_NO_FORNO = 3;
    PRONTO = 4;SAINDO = 5;
    BOLO_BOM = 0;BOLO_CRU = -1;BOLO_PASSADO = 1;
    
    if isempty(Estado) 
        
        Estado.Porta = 'Porta Fechada';
        Estado.Var.PosManipulador = -Objetos.refEscala;
        Estado.Var.VelManipulador = 0;
        Estado.Var.Ref = -Objetos.refEscala;
        
        Estado.Entrada = 'Entrada Espera';
        Estado.Var.tEntradaFuncionando = 0;
        
        Estado.Bolo(1).st = 'Em Espera';
        Estado.Bolo(2).st = 'Em Espera';
        Estado.Bolo(3).st = 'Em Espera';
        Estado.Bolo(4).st = 'Em Espera';
        Estado.Bolo(1).val = EM_ESPERA;
        Estado.Bolo(2).val = EM_ESPERA;
        Estado.Bolo(3).val = EM_ESPERA;
        Estado.Bolo(4).val = EM_ESPERA;
        Estado.Bolo(1).cond = BOLO_BOM;
        Estado.Bolo(2).cond = BOLO_BOM;
        Estado.Bolo(3).cond = BOLO_BOM;
        Estado.Bolo(4).cond = BOLO_BOM;
        Estado.Bolo(1).time = 0;
        Estado.Bolo(2).time = 0;
        Estado.Bolo(3).time = 0;
        Estado.Bolo(4).time = 0;
        Estado.Var.ProximoDaFila = 1;
        Estado.Var.tBoloCozinhando = 0;
        Estado.Var.tPortaAberta = 0;
        
        Estado.Manipulador = 'Sem Bolo';
        Estado.Var.BoloPronto = 0;
        Estado.Var.BoloNoCentro = 0;
        
        Estado.Saida = 'Saida Espera';
        Estado.Var.BoloNaSaida = 0;
        Estado.Var.tSaidaFuncionando = 0;
        
        Estado.Var.RegistroSaida = [0 0 0];
        Estado.Var.flagLimitePolias = 0;
        Estado.Var.maxPortaAberta = 0;
        Estado.Var.maxExcessoNoForno = 0;
        
        return;
        
    end % if isempty(Estado)
    
    
    %% transio de estado da porta do forno
    switch Estado.Porta
        
        case 'Porta Fechada' 
            
            % verifica condio pra transio de estado
            if ((Estado.Var.Ref == -Objetos.refEscala) &&...
                (Estado.Var.PosManipulador > Objetos.sensor2PosX)) ||...
               ((Estado.Var.Ref == Objetos.refEscala) &&...
                (Estado.Var.PosManipulador < Objetos.sensor1PosX))
           
               % animando porta abrindo e mudando estado
               set(Objetos.portaForno,'YData',...
                   get(Objetos.portaForno,'YData') - Objetos.deslocPorta);
               Estado.Porta = 'Porta Aberta';
               
            end % if condio de transio
            
        case 'Porta Aberta'
            
            % verifica condio pra transio de estado
            if ((Estado.Var.Ref == -Objetos.refEscala) &&...
                (Estado.Var.PosManipulador <= Objetos.sensor2PosX)) ||...
               ((Estado.Var.Ref == Objetos.refEscala) &&...
                (Estado.Var.PosManipulador >= Objetos.sensor1PosX))
           
               % animando porta fechando e mudando estado
               set(Objetos.portaForno,'YData',...
                   get(Objetos.portaForno,'YData') + Objetos.deslocPorta);
               Estado.Porta = 'Porta Fechada';
               
            end % if condio de transio
        
    end % switch Estado.Porta
    
    %% transio de estado da esteira de entrada
    switch Estado.Entrada
        
        case 'Entrada Espera' 
            
            % verifica condio pra transio de estado
            if (Estado.Var.BoloNoCentro == 0)
           
               Estado.Var.tEntradaFuncionando = 0;
               Estado.Entrada = 'Entrada Funcionando';
               
            end % if condio de transio
            
        case 'Entrada Funcionando'
            
            % verificando id do bolo que est entrando
            idBolo = find([Estado.Bolo(:).val] == ENTRANDO);
            
            if ~isempty(idBolo) % se h um bolo entrando
                Estado.Var.tEntradaFuncionando =...
                    Estado.Var.tEntradaFuncionando + 1;
            end
            
            % verifica condio pra transio de estado
            if Estado.Var.tEntradaFuncionando > TEMPO_ESTEIRA*fps
           
               Estado.Var.BoloNoCentro = 1;
               Estado.Entrada = 'Entrada Espera';
               
            else % ao do estado

                if ~isempty(idBolo) % se h um bolo entrando

                    % anima bolo entrando
                    set(Objetos.bolos(idBolo),'XData',...
                        get(Objetos.bolos(idBolo),'XData') +...
                        1.3*Objetos.refEscala/(TEMPO_ESTEIRA*fps)); % andar 1.3m/s

                    % anima eixo de entrada
                    dtheta = (1.3/0.2)/(TEMPO_ESTEIRA*fps);% theta*r = c/fps
                    M = [cos(dtheta),sin(dtheta);-sin(dtheta),cos(dtheta)];
                    Objetos.entradaEixoP = M*Objetos.entradaEixoP; % rotaciona eixo
                    set(Objetos.entradaEixo,...
                        'XData',Objetos.eixoEntradaPosX2 +...
                                Objetos.entradaEixoP(1,:),...
                        'YData',Objetos.eixoEntradaPosY2 +...
                                Objetos.entradaEixoP(2,:)    );

                end % if ~isempty(idBolo)
                
            end % condio de transio
            
    end % switch Estado.Entrada  
    
    %% transio de estado dos bolos
    for idBolo = 1:4
        
        switch Estado.Bolo(idBolo).st
        
            case 'Em Espera' 

                % verifica condio pra transio de estado
                if (idBolo == Estado.Var.ProximoDaFila) &&...
                   (strcmp(Estado.Entrada,'Entrada Funcionando'))
           
                    Estado.Bolo(idBolo).st = 'Entrando';
                    Estado.Bolo(idBolo).val = ENTRANDO;
               
                end % if condio de transio
                
            case 'Entrando'
                
                % verifica condio pra transio de estado
                if Estado.Var.BoloNoCentro == 1;
           
                    Estado.Bolo(idBolo).cond = BOLO_BOM;
                    Estado.Bolo(idBolo).time = 0;
                    Estado.Var.tBoloCozinhando = 0;
                    Estado.Var.tPortaAberta = 0;
                    Estado.Var.ProximoDaFila = mod(idBolo,4)+1;
                    Estado.Bolo(idBolo).st = 'Centro';
                    Estado.Bolo(idBolo).val = CENTRO;         
               
                end % if condio de transio
                
            case 'Centro'
                
                Estado.Var.tBoloCozinhando =...
                    Estado.Var.tBoloCozinhando + 1;
                
                % verifica condio pra transio de estado
                if Estado.Var.tBoloCozinhando > TEMPO_BOLO_PRONTO*fps
                    
                    Estado.Var.BoloPronto = 1;
                    Estado.Var.tBoloCozinhando = 0; % reiniciando contador
                    Estado.Bolo(idBolo).st = 'Pronto no Forno';
                    Estado.Bolo(idBolo).val = PRONTO_NO_FORNO;
                    
                elseif strcmp(Estado.Porta,'Porta Fechada')
                    
                    % atualizando cozimento do bolo
                    set(Objetos.bolos(idBolo),'FaceColor',...
                        get(Objetos.bolos(idBolo),'FaceColor') +... 
                        (Objetos.corBoloPronto - Objetos.corBoloCru)/...
                        (TEMPO_BOLO_PRONTO*fps - TEMPO_LIM_PORTA_ABERTA*fps));
                      
                else % porta aberta
                    
                    Estado.Var.tPortaAberta =...
                        Estado.Var.tPortaAberta + 1;
                    
                    if Estado.Var.tPortaAberta > TEMPO_LIM_PORTA_ABERTA*fps
                        Estado.Bolo(idBolo).cond = BOLO_CRU;
                        Estado.Bolo(idBolo).time = Estado.Var.tPortaAberta;
                    end
                        
                end % if condio de transio
                
            case 'Pronto no Forno'
                
                Estado.Var.tBoloCozinhando =...
                    Estado.Var.tBoloCozinhando + 1;
                
                % verifica condio pra transio de estado
                if mean(get(Objetos.bolos(idBolo),'XData')) >=...
                                        Objetos.sensor1PosX
                    
                    Estado.Bolo(idBolo).st = 'Pronto';
                    Estado.Bolo(idBolo).val = PRONTO; 
                    
                elseif Estado.Var.tBoloCozinhando > TEMPO_BOLO_PASSADO*fps
                    
                    Estado.Bolo(idBolo).cond = BOLO_PASSADO;
                    Estado.Bolo(idBolo).time = Estado.Var.tBoloCozinhando;
                    
                    % queimando o bolo
                    set(Objetos.bolos(idBolo),'FaceColor',...
                        get(Objetos.bolos(idBolo),'FaceColor')*...
                        exp((TEMPO_BOLO_PASSADO*fps-...
                             Estado.Var.tBoloCozinhando)*0.1));
                    
                end % if condio de transio
                
            case 'Pronto'
                
                % verifica condio pra transio de estado
                if Estado.Var.BoloNaSaida == 1
                    
                    Estado.Bolo(idBolo).st = 'Saindo';
                    Estado.Bolo(idBolo).val = SAINDO; 
                    
                end % if condio de transio
                
            case 'Saindo'
                
                % verifica condio pra transio de estado
                if Estado.Var.BoloNaSaida == 0
                    
                    % posiciona bolo no incio
                    set(Objetos.bolos(idBolo),'XData',...
                        Objetos.bolosBaseX + Objetos.bolosPosX0);
                    set(Objetos.bolos(idBolo),'FaceColor',...
                        Objetos.corBoloCru);
                    Estado.Bolo(idBolo).st = 'Em Espera';
                    Estado.Bolo(idBolo).val = EM_ESPERA; 
                    
                end % if condio de transio
                 
        end % switch Estado.Bolo(idBolo).st
        
    end % for idBolo
    
    %% transio de estado do manipulador
    
    % verificando se manipulador ultrapassou os limites permitidos
    if Estado.Var.PosManipulador < Objetos.eixoCorreiaPosX1-TOL_SOBRESSINAL   
        if Estado.Var.PosManipulador < Estado.Var.flagLimitePolias
            Estado.Var.flagLimitePolias = Estado.Var.PosManipulador;
        end
    elseif Estado.Var.PosManipulador > Objetos.motorPosX + TOL_SOBRESSINAL
        if Estado.Var.PosManipulador > Estado.Var.flagLimitePolias
            Estado.Var.flagLimitePolias = Estado.Var.PosManipulador;
        end
    end
    
    % atualizando posio do manipulador
    set(Objetos.manipulador,'XData',...
        Objetos.manipuladorBaseX + Estado.Var.PosManipulador);
    set(Objetos.manipuladorSinal,'XData',...
        Estado.Var.PosManipulador);
    
    % atualizando posio do eixo do motor
    theta = -(Estado.Var.PosManipulador + 1)/(0.2*0.5*Objetos.refEscala); % theta*r = l
    M = [cos(theta),sin(theta);-sin(theta),cos(theta)];
    Pact = M*Objetos.motorEixoP;
    set(Objetos.motorEixo,...
        'XData',Pact(1,:) + Objetos.motorPosX,...
        'YData',Pact(2,:) + Objetos.motorPosY);
    
    % verificando se o manipulador est aproximadamente parado
    manipuladorParado = 0; 
    if abs(Estado.Var.VelManipulador) <= CRITERIO_PARADA_VEL
        if Estado.Var.Ref > 0
            if abs(Estado.Var.PosManipulador-Estado.Var.Ref) <=...
               (1-(-1))*Objetos.refEscala*CRITERIO_PARADA_POS_POSIT
                manipuladorParado = 1;
            end
        else % Estado.Var.Ref < 0
            if abs(Estado.Var.PosManipulador-Estado.Var.Ref) <=...
               (1-(-1))*Objetos.refEscala*CRITERIO_PARADA_POS_NEGAT
                manipuladorParado = 1;
            end
        end
    end
         
    % verificando estado do manipulador
    switch Estado.Manipulador
        
        case 'Sem Bolo' 
            
            % verifica condio pra transio de estado
            if (Estado.Var.BoloPronto == 1) &&...
               (manipuladorParado) && ...
               (strcmp(Estado.Saida,'Saida Espera'))
           
                Estado.Var.BoloPronto = 0;
                Estado.Var.BoloNoCentro = 0;
                Estado.Var.Ref = +Objetos.refEscala;
                set(Objetos.manipuladorSinal,'Color','g',...
                    'MarkerFaceColor','g');
                Estado.Manipulador = 'Com Bolo';
               
            end % if condio de transio
            
        case 'Com Bolo'
            
            % verifica condio pra transio de estado
            if manipuladorParado
           
                Estado.Var.BoloNaSaida = 1;
                Estado.Var.Ref = -Objetos.refEscala;
                set(Objetos.manipuladorSinal,'Color','r',...
                    'MarkerFaceColor','r');
                Estado.Manipulador = 'Sem Bolo';
               
            else % ao do estado
            
                % verificando id do bolo que est no manipulador
                idBolo = find(...
                    ([Estado.Bolo(:).val] == PRONTO_NO_FORNO) |...
                    ([Estado.Bolo(:).val] == PRONTO)            );
                
                % verificando caso em que o manipulador no conseguiu pegar
                % os bolos ainda (existe mais de um bolo pronto)
                if length(idBolo) > 1
                    minDist = 2*Objetos.refEscala;
                    minBolo = idBolo(1);
                    for ind = 1:length(idBolo)
                        boPos = mean(get(Objetos.bolos(idBolo(ind)),'XData'));
                        if minDist < abs(boPos-Estado.Var.PosManipulador)
                            minDist = abs(boPos-Estado.Var.PosManipulador);
                            minBolo = idBolo(ind);
                        end
                    end
                    idBolo = minBolo; % o bolo que realmente est com o 
                    % manipulador  o que est mais prximo dele
                end

                if ~isempty(idBolo) % se h um bolo no manipulador

                    % anima bolo andando
                    set(Objetos.bolos(idBolo),'XData',...
                        Objetos.bolosBaseX + Estado.Var.PosManipulador);

                end % if ~isempty(idBolo)
                
            end % condio de transio
            
    end % switch Estado.Manipulador 
    
        
    %% transio de estado da esteira de sada
    switch Estado.Saida

        case 'Saida Espera' 
            
            % verifica condio pra transio de estado
            if Estado.Var.BoloNaSaida == 1
           
               Estado.Var.tSaidaFuncionando = 0;
               Estado.Saida = 'Saida Funcionando';
               
            end % if condio de transio
            
        case 'Saida Funcionando'
            
            % verificando id do bolo que est saindo
            idBolo = find([Estado.Bolo(:).val] == SAINDO);
            
            if ~isempty(idBolo) % se h um bolo saindo
                Estado.Var.tSaidaFuncionando =...
                    Estado.Var.tSaidaFuncionando + 1;
            end
            
            % verifica condio pra transio de estado
            if Estado.Var.tSaidaFuncionando > TEMPO_ESTEIRA*fps % 1s
           
                Estado.Var.BoloNaSaida = 0;
                Estado.Saida = 'Saida Espera';
                
                if Estado.Bolo(idBolo).cond == BOLO_BOM
                    Estado.Var.RegistroSaida(2) =...
                        Estado.Var.RegistroSaida(2) + 1;
                elseif Estado.Bolo(idBolo).cond == BOLO_CRU
                    Estado.Var.RegistroSaida(1) =...
                        Estado.Var.RegistroSaida(1) + 1;
                    if Estado.Bolo(idBolo).time > Estado.Var.maxPortaAberta
                        Estado.Var.maxPortaAberta = Estado.Bolo(idBolo).time;
                    end
                else % BOLO_PASSADO
                    Estado.Var.RegistroSaida(3) =...
                        Estado.Var.RegistroSaida(3) + 1;
                    if Estado.Bolo(idBolo).time > Estado.Var.maxExcessoNoForno
                        Estado.Var.maxExcessoNoForno = Estado.Bolo(idBolo).time;
                    end
                end
                
                % mostrando diagnstico
                clc % apagando tela
                disp('Bolos Concludos: ');
                disp(['crs: ' num2str(Estado.Var.RegistroSaida(1))]);
                disp(['bons: ' num2str(Estado.Var.RegistroSaida(2))]);
                disp(['passados: ' num2str(Estado.Var.RegistroSaida(3))]);
                disp(' ');
                if (Estado.Var.flagLimitePolias ~= 0) || ...
                   (Estado.Var.RegistroSaida(1) ~= 0) || ...
                   (Estado.Var.RegistroSaida(3) ~= 0)
                    disp('Ocorrncias: ');
                    
                end
                if Estado.Var.flagLimitePolias ~= 0 
                    disp(['- manipulador ultrapassou polias, chegando em '...
                              num2str(Estado.Var.flagLimitePolias) 'm']);
                end
                if Estado.Var.RegistroSaida(1) ~= 0
                    disp(['- porta do forno chegou a ficar aberta por '...
                              num2str(Estado.Var.maxPortaAberta/fps) 's']);
                end
                if Estado.Var.RegistroSaida(3) ~= 0
                    disp(['- bolo queimou, ficando no forno por '...
                              num2str(Estado.Var.maxExcessoNoForno/fps) 's']);
                end 
                disp(' ');
                if Estado.Var.flagLimitePolias ~= 0 
                    disp('- Ajuste o sobressinal para os requisitos');
                    disp('  da planta, para evitar que o manipulador');
                    disp('  ultrapasse as polias.');   
                end
                if Estado.Var.RegistroSaida(1) ~= 0
                    disp('- Diminua o tempo de subida do controlador');
                    disp('  que atua quando o manipulador busca o bolo');
                    disp('  dentro do forno, de forma a manter a porta');
                    disp('  aberta o mnimo possvel.');
                end
                if Estado.Var.RegistroSaida(3) ~= 0
                    disp('- Diminua o tempo de subida do controlador');
                    disp('  que atua quando o manipulador tira o bolo');
                    disp('  do forno, de forma a evitar que o bolo queime.');
                end
               
            else % ao do estado
            
                if ~isempty(idBolo) % se h um bolo saindo

                    % anima bolo saindo
                    set(Objetos.bolos(idBolo),'XData',...
                        get(Objetos.bolos(idBolo),'XData') +...
                        1.3*Objetos.refEscala/(TEMPO_ESTEIRA*fps)); % andar 1.3m/s

                    % anima eixo de sada
                    dtheta = (1.3/0.2)/(TEMPO_ESTEIRA*fps); % theta*r = c/fps
                    M = [cos(dtheta),sin(dtheta);-sin(dtheta),cos(dtheta)];
                    Objetos.saidaEixoP = M*Objetos.saidaEixoP; % rotaciona eixo
                    set(Objetos.saidaEixo,...
                        'XData',Objetos.eixoSaidaPosX2 +...
                                Objetos.saidaEixoP(1,:),...
                        'YData',Objetos.eixoSaidaPosY2 +...
                                Objetos.saidaEixoP(2,:)    );

                end % if ~isempty(idBolo)
                
            end % condio de transio
            
    end % switch Estado.Saida
        

end % function modeloPlanta