function Objetos = plotaPlanta(figID)

    %% inicializando figura
    if isempty(figID)
        figID = figure('MenuBar','none','Color',[1,1,1]);hold on;
        StartStop = uicontrol('Parent',figID,'Style','pushbutton',...
                              'String','Start',...
                              'Units','Normalized','Position',[0 0 1 0.1]);   
    else % caso no esteja vazio, resetar a planta da figura figID
        figure(figID);
        delete(get(figID,'Children'));hold on;
        StartStop = uicontrol('Parent',figID,'Style','pushbutton',...
                              'String','Start',...
                              'Units','Normalized','Position',[0 0 1 0.1]);
    end % if isempty(figID)
        

    %% plotando objetos estticos

    % referncia (meia amplitude do degrau)
    refEscala = 3;
    
    % meio crculo
    theta = linspace(-pi/2,pi/2,10);
    rho = 1 + 0*theta;
    [xcirc,ycirc] = pol2cart(theta,rho);

    % motor
    motorPosX = 1.0*refEscala;
    motorPosY = 1.2*refEscala;
    motorEscala = 0.2*refEscala;
    motor = fill([-xcirc,xcirc]*motorEscala + motorPosX,...
                 [-ycirc,ycirc]*motorEscala + motorPosY,...
                 [0,0,0]);

    % correia dentada
    eixoCorreiaPosX1 = -1.4*refEscala;
    eixoCorreiaPosY1 = motorPosY;
    eixoCorreiaPosX2 = motorPosX;
    eixoCorreiaPosY2 = motorPosY;
    correiaEscala = 0.5*motorEscala;
    correia = plot([-xcirc*correiaEscala + eixoCorreiaPosX1,...
                     xcirc*correiaEscala + eixoCorreiaPosX2,...
                     eixoCorreiaPosX1],...
                   [-ycirc*correiaEscala + eixoCorreiaPosY1,...
                     ycirc*correiaEscala + eixoCorreiaPosY2,...
                     ycirc(end)*correiaEscala + eixoCorreiaPosY1],...
                   '--','Color',[0.5,0.5,0.5]);
    corRolamento1 = fill([-xcirc,xcirc]*correiaEscala+eixoCorreiaPosX1,...
                         [-ycirc,ycirc]*correiaEscala+eixoCorreiaPosY1,...
                         [0.5,0.5,0.5]);
    corPolia1 = plot([-xcirc,xcirc]*correiaEscala+eixoCorreiaPosX1,...
                     [-ycirc,ycirc]*correiaEscala+eixoCorreiaPosY1,...
                     'Color',[0.8,0.8,0.8],'LineWidth',1.5);
    corRolamento2 = fill([-xcirc,xcirc]*correiaEscala+eixoCorreiaPosX2,...
                         [-ycirc,ycirc]*correiaEscala+eixoCorreiaPosY2,...
                         [0.5,0.5,0.5]);
    corPolia2 = plot([-xcirc,xcirc]*correiaEscala+eixoCorreiaPosX2,...
                     [-ycirc,ycirc]*correiaEscala+eixoCorreiaPosY2,...
                     'Color',[0.8,0.8,0.8],'LineWidth',1.5);
                 
    % sensores
    sensor1PosX = refEscala - 0.2*2*refEscala;
    sensor2PosX = -sensor1PosX;
    sensor1PosY = eixoCorreiaPosY1 - 0.8*correiaEscala;
    sensor2PosY = sensor1PosY;
    sensorTamanho = 0.02*refEscala;
    fill([-1,1,1,-1]*sensorTamanho + sensor1PosX,...
         [1,1,-1,-1]*sensorTamanho + sensor1PosY,[1,0,1]);
    fill([-1,1,1,-1]*sensorTamanho + sensor2PosX,...
         [1,1,-1,-1]*sensorTamanho + sensor2PosY,[1,0,1]);
    

    % esteira entrada
    eixoEntradaPosX1 = -5*refEscala;
    eixoEntradaPosY1 = -1*refEscala;
    eixoEntradaPosX2 = -0.5*refEscala;
    eixoEntradaPosY2 = eixoEntradaPosY1;
    entradaEscala = 0.2*refEscala;
    entrada = plot([-xcirc*entradaEscala + eixoEntradaPosX1,...
                     xcirc*entradaEscala + eixoEntradaPosX2,...
                     eixoEntradaPosX1],...
                   [-ycirc*entradaEscala + eixoEntradaPosY1,...
                     ycirc*entradaEscala + eixoEntradaPosY2,...
                     ycirc(end)*entradaEscala + eixoEntradaPosY1],...
                   '--','Color',[0,0,1]);
    entPolia1 = plot([-xcirc,xcirc]*entradaEscala + eixoEntradaPosX1,...
                     [-ycirc,ycirc]*entradaEscala + eixoEntradaPosY1,...
                     'Color',[0,0,1],'LineWidth',1.5);
    entPolia2 = plot([-xcirc,xcirc]*entradaEscala + eixoEntradaPosX2,...
                     [-ycirc,ycirc]*entradaEscala + eixoEntradaPosY2,...
                     'Color',[0,0,1],'LineWidth',1.5);

    % esteira sada
    eixoSaidaPosX1 = 5*refEscala;
    eixoSaidaPosY1 = -1*refEscala;
    eixoSaidaPosX2 = 0.5*refEscala;
    eixoSaidaPosY2 = eixoSaidaPosY1;
    saidaEscala = 0.2*refEscala;
    saida = plot([-xcirc*saidaEscala + eixoSaidaPosX1,...
                   xcirc*saidaEscala + eixoSaidaPosX2,...
                   eixoSaidaPosX1],...
                 [-ycirc*saidaEscala + eixoSaidaPosY1,...
                   ycirc*saidaEscala + eixoSaidaPosY2,...
                   ycirc(end)*saidaEscala + eixoSaidaPosY1],...
                 '--','Color',[0,1,0]);
    saidaPolia1 = plot([-xcirc,xcirc]*saidaEscala + eixoSaidaPosX1,...
                       [-ycirc,ycirc]*saidaEscala + eixoSaidaPosY1,...
                       'Color',[0,1,0],'LineWidth',1.5);
    saidaPolia2 = plot([-xcirc,xcirc]*saidaEscala + eixoSaidaPosX2,...
                       [-ycirc,ycirc]*saidaEscala + eixoSaidaPosY2,...
                       'Color',[0,1,0],'LineWidth',1.5);

    % forno
    fornoPosX = -1*refEscala;
    fornoPosY = 0*refEscala;
    escalaFornoX = 1*refEscala;
    escalaFornoY = 1.4*refEscala;
    forno = plot([  1,1,-1,-1, 1,   1]*escalaFornoX + fornoPosX,...
                 [0.85,1, 1,-1,-1,-0.6]*escalaFornoY + fornoPosY,...
                 'Color',[0.8,0.3,0],'LineWidth',2);

             
    %% Plotando Objetos Mveis

    % bolos
    bolosPosX0 = -2.3*refEscala;
    bolosPosY0 = -0.6*refEscala;
    bolosEscala = 0.3*refEscala;
    bolosBaseX = [-1,1,1,-1]*bolosEscala;
    corBoloCru = [0.9,0.9,0];
    corBoloPronto = [0.6,0.6,0];
    bolos(1) = fill([-1,1,1,-1]*bolosEscala + bolosPosX0,...
                0.6*[1,1,-1,-1]*bolosEscala + bolosPosY0,corBoloCru);
    bolos(2) = fill([-1,1,1,-1]*bolosEscala + bolosPosX0,...
                0.6*[1,1,-1,-1]*bolosEscala + bolosPosY0,corBoloCru);
    bolos(3) = fill([-1,1,1,-1]*bolosEscala + bolosPosX0,...
                0.6*[1,1,-1,-1]*bolosEscala + bolosPosY0,corBoloCru);
    bolos(4) = fill([-1,1,1,-1]*bolosEscala + bolosPosX0,...
                0.6*[1,1,-1,-1]*bolosEscala + bolosPosY0,corBoloCru);
    
    
    % manipulador
    manipuladorPosX0 = -1*refEscala;
    manipuladorPosY0 = bolosPosY0 + bolosEscala*0.6;
    manipuladorEscalaX = bolosEscala;
    manipuladorEscalaY = (eixoCorreiaPosY1-correiaEscala)-manipuladorPosY0;
    manipulador = plot([0,0,-1,1]*manipuladorEscalaX + manipuladorPosX0,...
                       [1,0, 0,0]*manipuladorEscalaY + manipuladorPosY0,...
                       'k','LineWidth',2);
    manipuladorSinal = plot(manipuladorPosX0,manipuladorPosY0,...
                            'or','MarkerFaceColor','r');
    manipuladorBaseX = [0,0,-1,1]*manipuladorEscalaX;

    % porta do forno
    deslocPorta = 2*refEscala;
    portaForno = plot([   1,   1]*escalaFornoX + fornoPosX,...
                      [-0.6,0.85]*escalaFornoY + fornoPosY,...
                      'Color',[1,0.2,0.2],'LineWidth',4);

    % motor eixo
    motorEixoP = [0,0;...
                  0,1]*motorEscala*0.5;
    motorEixo = plot(motorEixoP(1,:) + motorPosX,...
                     motorEixoP(2,:) + motorPosY,...
                     'Color',[0.8,0.8,0.8],'LineWidth',1.5);

    % entrada eixo
    entradaEixoP = [0,0;...
                    0,1]*entradaEscala;
    entradaEixo = plot(entradaEixoP(1,:) + eixoEntradaPosX2,...
                       entradaEixoP(2,:) + eixoEntradaPosY2,...
                       'Color',[0,0,1],'LineWidth',1.5);

    % sada eixo
    saidaEixoP = [0,0;...
                  0,1]*saidaEscala;
    saidaEixo = plot(saidaEixoP(1,:) + eixoSaidaPosX2,...
                     saidaEixoP(2,:) + eixoSaidaPosY2,...
                     'Color',[0,1,0],'LineWidth',1.5);

                 
    %% corrigindo posio e formato da imagem
    axis off;
    axis equal;xlim([-2 2]*refEscala);ylim([-1.6,1.6]*refEscala);

    
    %% salvando struct Objetos

    Objetos.figID = figID;
    Objetos.StartStop = StartStop;
    
    Objetos.refEscala = refEscala;
    
    Objetos.sensor1PosX = sensor1PosX;
    Objetos.sensor2PosX = sensor2PosX;

    Objetos.bolos = bolos;
    Objetos.bolosBaseX = bolosBaseX;
    Objetos.bolosPosX0 = bolosPosX0;
    Objetos.corBoloCru = corBoloCru;
    Objetos.corBoloPronto = corBoloPronto;

    Objetos.manipulador = manipulador;
    Objetos.manipuladorBaseX = manipuladorBaseX;
    Objetos.manipuladorSinal = manipuladorSinal;

    Objetos.portaForno = portaForno;
    Objetos.deslocPorta = deslocPorta;

    Objetos.motorEixoP = motorEixoP;
    Objetos.motorPosX = motorPosX;
    Objetos.motorPosY = motorPosY;
    Objetos.motorEixo = motorEixo;
    
    Objetos.eixoCorreiaPosX1 = eixoCorreiaPosX1;

    Objetos.entradaEixoP = entradaEixoP;
    Objetos.eixoEntradaPosX2 = eixoEntradaPosX2;
    Objetos.eixoEntradaPosY2 = eixoEntradaPosY2;
    Objetos.entradaEixo = entradaEixo;

    Objetos.saidaEixoP = saidaEixoP;
    Objetos.eixoSaidaPosX2 = eixoSaidaPosX2;
    Objetos.eixoSaidaPosY2 = eixoSaidaPosY2;
    Objetos.saidaEixo = saidaEixo;

end % function plotaPlanta



