function [tVec,ref,pot,tac,uctrl] = osciloscopio(Fa,funControle)

    % definindo perodo de amostragem
    Ta = 1/Fa;
    
    % criando figura
    figID = figure('MenuBar','none','ToolBar','none',...
                   'CloseRequestFcn',@pararOsciloscopio);
    botaoStop = uicontrol('Parent',figID,'Style','pushbutton',...
                          'String','Stop','Callback',@pararOsciloscopio,...
                          'Units','Normalized','Position',[0.9 0 0.1 0.1]);
    pHandle = plot(0,0,'ro-');hold on;grid minor;
    wHandle = plot(0,0,'go-');hold on;grid minor;
    uHandle = plot(0,0,'bo-');hold on;grid minor;
    txFaHandle = text(1,1,['F_A = ' num2str(1/Ta) 'Hz'],...
                    'HorizontalAlignment','right',...
                    'VerticalAlignment','bottom',...
                    'Units','Normalized');
    legend('\theta_{P}','\omega_{T}','u','Location','NorthWest');
    
    % Setup da placa de aquisicao
    ai = analoginput('nidaq','Dev1');ao = analogoutput('nidaq','Dev1');
    addchannel(ai,0:2);addchannel(ao,0);
    set(ai,'ChannelSkewMode','Equisample');ai.ChannelSkew;
    
    % iniciando vetores para salvar os valores no tempo
    tVec = [];ref = [];pot = [];tac = [];uctrl = [];ik = 0;
    
    % levando motor pra posio inicial nula
    returningToPos0(ai,ao,0);
    
    % iniciando registro de tempo de execuo
    tSim = tic;tPrev = toc(tSim);
    
    % criando e iniciando timer
    tm = timer('ExecutionMode','fixedRate','Period',Ta,...
               'TimerFcn',@ExecuteTimer);start(tm);
    
    % pausando funo
    uiwait(figID);
           
    
    % funo executada pelo timer
    function ExecuteTimer(~,~)
        
        % calculando tempo atual e amostragem real
        tAct = toc(tSim);TaReal = tAct - tPrev;
        
        % adquirindo input
        sample = getsample(ai);
        rk = sample(1);pk = sample(2);wk = sample(3);
        
        % calculando controle
        [uk,ik] = funControle(tAct,tPrev,rk,pk,wk,ik);
        
        % saturando e enviando output
        if abs(uk) > 5
            uk = sign(uk)*5;
        end
        putsample(ao,uk);
        tPrev = tAct;
        
        % atualizando vetores
        tVec(end+1) = tAct;
        ref(end+1) = rk;
        pot(end+1) = pk;
        tac(end+1) = wk;
        uctrl(end+1) = uk;
        
        % atualizando grficos
        set(pHandle,'XData',tVec,'YData',pot);
        set(wHandle,'XData',tVec,'YData',tac);
        set(uHandle,'XData',tVec,'YData',uctrl);
        set(txFaHandle,'String',['F_A = ' num2str(round(1/TaReal)) 'Hz']);
        
    end % function ExecuteTimer(~,~)
    
    % funo executada quando o boto  pressionado
    function pararOsciloscopio(~,~)
        
        delete(botaoStop);   % deletando boto
        putsample(ao,0);     % interrompendo movimento do motor
        stop(tm);delete(tm); % finalizando timer
        uiresume(figID);     % retornando a execuo da funo
        
        % destacando valores em regime estacionrio
        if length(uctrl) > Fa
            text(max(get(gca,'XLim')),mean(pot(end-Fa:end)),...
                 [' ' num2str(mean(pot(end-Fa:end)),'%.2f') 'V'],...
                 'Color',[1,0,0]);
            text(max(get(gca,'XLim')),mean(tac(end-Fa:end)),...
                 [' ' num2str(mean(tac(end-Fa:end)),'%.2f') 'V'],...
                 'Color',[0,0.7,0]);
            text(max(get(gca,'XLim')),mean(uctrl(end-Fa:end)),...
                 [' ' num2str(mean(uctrl(end-Fa:end)),'%.2f') 'V'],...
                 'Color',[0,0,1]);
        end % apenas se a simulao ocorreu por mais de 1s
         
        % restaurando caractersticas normais da figura
        set(figID,'MenuBar','figure','Toolbar','figure',...
            'CloseRequestFcn',@delete);
        
    end % function CloseFigure(src,evnt)

end % function [input,output] = osciloscopio